# Changelog

## [2.9.0](https://github.com/AEGIS-GAME/aegis/compare/client-v2.8.2...client-v2.9.0) (2025-09-16)


### Features

* **aegis:** working on adding client update feature ([e60f399](https://github.com/AEGIS-GAME/aegis/commit/e60f399553ab86282a153004cbcc2751371a94dc))
* **client:** update client feature ([41963ac](https://github.com/AEGIS-GAME/aegis/commit/41963ac38061bdfd20b010933603e7a94a80a10e))
* **client:** updating client works i think ([0e3e6d9](https://github.com/AEGIS-GAME/aegis/commit/0e3e6d99776d6439f204458fbc90b2a4600c476a))


### Bug Fixes

* add things ([425a407](https://github.com/AEGIS-GAME/aegis/commit/425a407464e62a06eefc8f03aabc418a01f0fe59))
* client jsut checks version mismatch, aegis update just downloads ([85877fa](https://github.com/AEGIS-GAME/aegis/commit/85877fa7f45afe54710a6d071553e8604dc96967))
* **client world picker:** multiselect back to single for now in client only ([#12](https://github.com/AEGIS-GAME/aegis/issues/12)) ([4f66834](https://github.com/AEGIS-GAME/aegis/commit/4f66834bfe9bf251862e33cda2adfebd68ddc493))
* **client:** change thing ([fa6e967](https://github.com/AEGIS-GAME/aegis/commit/fa6e967c3bcee38c59f4e258ba36ffed17f7ae42))
* **client:** dismissal of update banner if u wanna ([6279ff0](https://github.com/AEGIS-GAME/aegis/commit/6279ff007d1e76a6adf3c8e9f97d5cf0a5e7cc35))
* **client:** forgot i changed version for testing ([03d942c](https://github.com/AEGIS-GAME/aegis/commit/03d942c1e34ac77e72c18f7302665afc80641505))
* **client:** only check client version once aegis path set ([c4c68d5](https://github.com/AEGIS-GAME/aegis/commit/c4c68d51efe47c5b75ecfb5e75f7350a20718163))
* **client:** open "view on github" in default browser instead of electron ([b4684c1](https://github.com/AEGIS-GAME/aegis/commit/b4684c16ba3e80680ae67fea05570daa95334293))
* **client:** show aegis version in client "about" section in settings ([31f523b](https://github.com/AEGIS-GAME/aegis/commit/31f523bc2f084a2b862d0798e77ca6a38fbca2d3))
* **client:** version banner should be checking for version properly now ([7a75ac8](https://github.com/AEGIS-GAME/aegis/commit/7a75ac8e9accebb2bfeceb5c7b4489ac3061eb51))
* **client:** whoops ([0b5ff85](https://github.com/AEGIS-GAME/aegis/commit/0b5ff85d7eebbf3b7de063fb05ad1764aef0bec9))
* **client:** wrong api ([61517ba](https://github.com/AEGIS-GAME/aegis/commit/61517baf84e0dc34a62ccc6c254daa11d0d988bf))
* **tryign to force a release:** hate google ([#50](https://github.com/AEGIS-GAME/aegis/issues/50)) ([93179c4](https://github.com/AEGIS-GAME/aegis/commit/93179c4935cf98ee3b50197d0a60b034db0905fd))
* **updating:** remove debug, check for None ([de94e55](https://github.com/AEGIS-GAME/aegis/commit/de94e55907452ff8a3a9a6707ead9d1ba2f95c21))
* **updating:** some things ([efcc5d0](https://github.com/AEGIS-GAME/aegis/commit/efcc5d0a332167388942b8ffdd0e5ff7cc502a81))
* using client-version.txt file for client version ([3fa68b1](https://github.com/AEGIS-GAME/aegis/commit/3fa68b1a468199095fc9571f15172c8c0c46f65e))
* **version:** set client and aegis to 2.6.3 ([511e742](https://github.com/AEGIS-GAME/aegis/commit/511e742296efca766fa2b6c7d4461b58a0a4998a))


### Miscellaneous Chores

* release 2.5.0 ([3eb076d](https://github.com/AEGIS-GAME/aegis/commit/3eb076dff4a0336558ca30647a628417b46666db))
* release 2.5.2 ([bdb4a12](https://github.com/AEGIS-GAME/aegis/commit/bdb4a12f48ffb9191d0097d9f3fd43f6e5323970))
* release 2.5.3 ([9572d85](https://github.com/AEGIS-GAME/aegis/commit/9572d8598bb30d72ded4806fcad0016a97316efe))
* release 2.5.3 ([#16](https://github.com/AEGIS-GAME/aegis/issues/16)) ([52a8fbf](https://github.com/AEGIS-GAME/aegis/commit/52a8fbfd5bc2bbdc5522a0857fe2beed37fcfa6c))
* release 2.5.4 ([#18](https://github.com/AEGIS-GAME/aegis/issues/18)) ([8053984](https://github.com/AEGIS-GAME/aegis/commit/8053984580d6df587a8ae074b3ed23ee328fe082))
* release 2.5.5 ([9e19f3f](https://github.com/AEGIS-GAME/aegis/commit/9e19f3fd94f699a51ad8b338c919b935f5f79464))
* **release:** release 2.5.5 ([38ae7fb](https://github.com/AEGIS-GAME/aegis/commit/38ae7fba94cc997121030b54e1028e8361021964))
* **release:** release 2.5.5 ([4eb5080](https://github.com/AEGIS-GAME/aegis/commit/4eb508056eebd89c6a7cc86ed980480bbf4634da))
* **release:** release 2.5.6 ([acd2330](https://github.com/AEGIS-GAME/aegis/commit/acd2330b75fec3d9dcf49e79406bf1dabc2d9b69))
* **release:** release 2.5.6 ([356597d](https://github.com/AEGIS-GAME/aegis/commit/356597d62a4afd2d9c6e0b32b2a02cd756f74845))
* **release:** release 2.5.6 ([dfba2f3](https://github.com/AEGIS-GAME/aegis/commit/dfba2f3aa87e85b7997fafd95e99b37ed30bafc7))
* **release:** release 2.5.7 ([5716303](https://github.com/AEGIS-GAME/aegis/commit/5716303fd91d26bb75d6472a978d38f5baae9791))
* **release:** release 2.5.8 ([55d5418](https://github.com/AEGIS-GAME/aegis/commit/55d54188ffed04bbfd9c6302e2678eedb11947a9))
* **release:** release 2.6.1 ([fac6d6a](https://github.com/AEGIS-GAME/aegis/commit/fac6d6aa2045e8a55613ef819fa848da18bc46dd))
* **release:** release 2.6.2 ([3a67a71](https://github.com/AEGIS-GAME/aegis/commit/3a67a7105dad112d8e03af9de96e18bf26fa0fd5))
* **release:** release 2.6.2 ([295ca06](https://github.com/AEGIS-GAME/aegis/commit/295ca06f80e56a78aef2fd22ba23cf6f9e424047))
* **release:** release 2.6.2 ([8787df7](https://github.com/AEGIS-GAME/aegis/commit/8787df78bc9b3420c6d1cae15ea6406de9cb11f0))
* **release:** release 2.6.3 ([68d85a4](https://github.com/AEGIS-GAME/aegis/commit/68d85a4961650ead3b355b284ff19803351cdbb3))
* **release:** release 2.6.4 ([bb90764](https://github.com/AEGIS-GAME/aegis/commit/bb90764535993a7d170bacab8c924196daa27781))
* **release:** release 2.6.4 ([713166e](https://github.com/AEGIS-GAME/aegis/commit/713166e8996bac1a9471ca294b0d1703ea17fe2f))
* **release:** release 2.7.0 ([f606992](https://github.com/AEGIS-GAME/aegis/commit/f606992695d07dded3787febced2586ca08e80e2))
* **release:** release 2.7.1 ([9d57c24](https://github.com/AEGIS-GAME/aegis/commit/9d57c2484cbb0bf5664c0dd25f7965a8cab027d2))
* **release:** release 2.7.2 ([6408364](https://github.com/AEGIS-GAME/aegis/commit/64083645be9da4aa46934313f9b4cba02c0ca6b9))
* **release:** release 2.7.3 ([0259bbb](https://github.com/AEGIS-GAME/aegis/commit/0259bbb85e855f16d0ea1550f98c29abbc113cc1))
* **release:** release 2.7.4 ([2b45653](https://github.com/AEGIS-GAME/aegis/commit/2b45653e3cf530ad437b13365e86cc6691fdfe4e))
* **release:** release 2.7.5 ([5531a56](https://github.com/AEGIS-GAME/aegis/commit/5531a566878ee494d18dac37d4f7d54b3b2273e5))
* **release:** release 2.7.6 ([c29bbe6](https://github.com/AEGIS-GAME/aegis/commit/c29bbe63290d54a2eb0ab313a30b50c1fe10713f))
* **release:** release 2.9.0 ([fc0ff78](https://github.com/AEGIS-GAME/aegis/commit/fc0ff780599cc237ae0406b4f5ae2d37b06d5ee4))

## [2.8.2](https://github.com/AEGIS-GAME/aegis/compare/client-v2.8.1...client-v2.8.2) (2025-09-15)


### Bug Fixes

* **client:** only check client version once aegis path set ([c4c68d5](https://github.com/AEGIS-GAME/aegis/commit/c4c68d51efe47c5b75ecfb5e75f7350a20718163))

## [2.8.1](https://github.com/AEGIS-GAME/aegis/compare/client-v2.8.0...client-v2.8.1) (2025-09-15)


### Bug Fixes

* add things ([425a407](https://github.com/AEGIS-GAME/aegis/commit/425a407464e62a06eefc8f03aabc418a01f0fe59))
* **client:** change thing ([fa6e967](https://github.com/AEGIS-GAME/aegis/commit/fa6e967c3bcee38c59f4e258ba36ffed17f7ae42))

## [2.8.0](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.6...client-v2.8.0) (2025-09-15)


### Features

* **client:** update client feature ([41963ac](https://github.com/AEGIS-GAME/aegis/commit/41963ac38061bdfd20b010933603e7a94a80a10e))


### Bug Fixes

* client jsut checks version mismatch, aegis update just downloads ([85877fa](https://github.com/AEGIS-GAME/aegis/commit/85877fa7f45afe54710a6d071553e8604dc96967))
* **client:** dismissal of update banner if u wanna ([6279ff0](https://github.com/AEGIS-GAME/aegis/commit/6279ff007d1e76a6adf3c8e9f97d5cf0a5e7cc35))
* **client:** open "view on github" in default browser instead of electron ([b4684c1](https://github.com/AEGIS-GAME/aegis/commit/b4684c16ba3e80680ae67fea05570daa95334293))
* **client:** show aegis version in client "about" section in settings ([31f523b](https://github.com/AEGIS-GAME/aegis/commit/31f523bc2f084a2b862d0798e77ca6a38fbca2d3))
* **client:** wrong api ([61517ba](https://github.com/AEGIS-GAME/aegis/commit/61517baf84e0dc34a62ccc6c254daa11d0d988bf))
* using client-version.txt file for client version ([3fa68b1](https://github.com/AEGIS-GAME/aegis/commit/3fa68b1a468199095fc9571f15172c8c0c46f65e))

## [2.7.6](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.5...client-v2.7.6) (2025-09-15)


### Miscellaneous Chores

* **release:** release 2.7.6 ([c29bbe6](https://github.com/AEGIS-GAME/aegis/commit/c29bbe63290d54a2eb0ab313a30b50c1fe10713f))

## [2.7.5](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.4...client-v2.7.5) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.5 ([5531a56](https://github.com/AEGIS-GAME/aegis/commit/5531a566878ee494d18dac37d4f7d54b3b2273e5))

## [2.7.4](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.3...client-v2.7.4) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.4 ([2b45653](https://github.com/AEGIS-GAME/aegis/commit/2b45653e3cf530ad437b13365e86cc6691fdfe4e))

## [2.7.3](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.2...client-v2.7.3) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.3 ([0259bbb](https://github.com/AEGIS-GAME/aegis/commit/0259bbb85e855f16d0ea1550f98c29abbc113cc1))

## [2.7.2](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.1...client-v2.7.2) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.2 ([6408364](https://github.com/AEGIS-GAME/aegis/commit/64083645be9da4aa46934313f9b4cba02c0ca6b9))

## [2.7.1](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.0...client-v2.7.1) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.1 ([9d57c24](https://github.com/AEGIS-GAME/aegis/commit/9d57c2484cbb0bf5664c0dd25f7965a8cab027d2))

## [2.7.0](https://github.com/AEGIS-GAME/aegis/compare/client-v2.6.4...client-v2.7.0) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.0 ([f606992](https://github.com/AEGIS-GAME/aegis/commit/f606992695d07dded3787febced2586ca08e80e2))

## [2.6.4](https://github.com/AEGIS-GAME/aegis/compare/client-v2.6.3...client-v2.6.4) (2025-09-12)


### Bug Fixes

* **tryign to force a release:** hate google ([#50](https://github.com/AEGIS-GAME/aegis/issues/50)) ([93179c4](https://github.com/AEGIS-GAME/aegis/commit/93179c4935cf98ee3b50197d0a60b034db0905fd))
